@@ -10,9 +10,9 @@ from jupyterlab_server.test_utils import expected_http_error
 @pytest.fixture
 def notebooks(jp_create_notebook, labserverapp):
     nbpaths = (
-        'notebook1.ipynb',
-        'jlab_test_notebooks/notebook2.ipynb',
-        'jlab_test_notebooks/level2/notebook3.ipynb'
+        "notebook1.ipynb",
+        "jlab_test_notebooks/notebook2.ipynb",
+        "jlab_test_notebooks/level2/notebook3.ipynb",
     )
     for nb in nbpaths:
         jp_create_notebook(nb)
@@ -20,7 +20,7 @@ def notebooks(jp_create_notebook, labserverapp):
 
 
 async def test_lab_handler(notebooks, jp_fetch):
-    r = await jp_fetch('lab', 'jlab_test_notebooks')
+    r = await jp_fetch("lab", "jlab_test_notebooks")
     assert r.code == 200
     # Check that the lab template is loaded
     html = r.body.decode()
@@ -30,7 +30,7 @@ async def test_lab_handler(notebooks, jp_fetch):
 
 async def test_notebook_handler(notebooks, jp_fetch):
     for nbpath in notebooks:
-        r = await jp_fetch('lab', nbpath)
+        r = await jp_fetch("lab", nbpath)
         assert r.code == 200
         # Check that the lab template is loaded
         html = r.body.decode()
@@ -39,5 +39,5 @@ async def test_notebook_handler(notebooks, jp_fetch):
 
 async def test_404(notebooks, jp_fetch):
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        await jp_fetch('foo')
+        await jp_fetch("foo")
     assert expected_http_error(e, 404)
